==> igniteui-react-16.16.2.tgz: package/esm5/lib/MoveFloatingPaneAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PaneDragAction } from "./PaneDragAction";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { PaneDragActionType_$type } from "./PaneDragActionType";
/**
 * @hidden
 */
var MoveFloatingPaneAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MoveFloatingPaneAction, _super);
    function MoveFloatingPaneAction() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(MoveFloatingPaneAction.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveFloatingPaneAction.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.d.d = this.f;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveFloatingPaneAction.prototype, "c", {
        get: function () {
            var ret_ = this.e.c("type");
            return EnumUtil.getEnumValue(PaneDragActionType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(PaneDragActionType_$type, a);
            this.e.i("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveFloatingPaneAction.prototype, "b", {
        get: function () {
            var ret_ = this.e.c("oldLocation");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.i("oldLocation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveFloatingPaneAction.prototype, "a", {
        get: function () {
            var ret_ = this.e.c("newLocation");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.i("newLocation", value_);
        },
        enumerable: false,
        configurable: true
    });
    MoveFloatingPaneAction.$t = markType(MoveFloatingPaneAction, 'MoveFloatingPaneAction', PaneDragAction.$);
    return MoveFloatingPaneAction;
}(PaneDragAction));
export { MoveFloatingPaneAction };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/MoveFloatingPaneAction.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { PaneDragAction } from "./PaneDragAction";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { PaneDragActionType_$type } from "./PaneDragActionType";
import { DockManagerPoint } from "./DockManagerPoint";
/**
 * @hidden
 */
var MoveFloatingPaneAction = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MoveFloatingPaneAction, _super);
    function MoveFloatingPaneAction() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.d = new WCNativeHelper();
        _this.f = null;
        return _this;
    }
    Object.defineProperty(MoveFloatingPaneAction.prototype, "e", {
        get: function () {
            return this.d;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveFloatingPaneAction.prototype, "nativeElement", {
        get: function () {
            return this.f;
        },
        set: function (a) {
            this.f = a;
            this.d.o = this.f;
        },
        enumerable: false,
        configurable: true
    });
    MoveFloatingPaneAction.prototype.setNativeElement = function (a) {
        this.nativeElement = a;
    };
    Object.defineProperty(MoveFloatingPaneAction.prototype, "c", {
        get: function () {
            var ret_ = this.e.n("type");
            ret_ = enumGetBox(PaneDragActionType_$type, EnumUtil.getEnumValue(PaneDragActionType_$type, this.e.f(PaneDragActionType_$type, ret_)));
            return EnumUtil.getEnumValue(PaneDragActionType_$type, ret_);
        },
        set: function (a) {
            var value_ = enumGetBox(PaneDragActionType_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.e.v("type", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveFloatingPaneAction.prototype, "b", {
        get: function () {
            var ret_ = this.e.m("oldLocation", function (a) { return new DockManagerPoint(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("oldLocation", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MoveFloatingPaneAction.prototype, "a", {
        get: function () {
            var ret_ = this.e.m("newLocation", function (a) { return new DockManagerPoint(); });
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.e.v("newLocation", value_);
        },
        enumerable: false,
        configurable: true
    });
    MoveFloatingPaneAction.$t = markType(MoveFloatingPaneAction, 'MoveFloatingPaneAction', PaneDragAction.$);
    return MoveFloatingPaneAction;
}(PaneDragAction));
export { MoveFloatingPaneAction };
